# Mest
ML Models on REST
A framework for developing a realtime model-inference service.

Allows you to set up an inference-endpoint for you ML Model easily.

Mest uses `Flask` for creating a lightweight WSGI web application, designed to run on Kubernetes

Docs can found here:
https://orlevi111.github.io/mest/
